@@ -306,6 +306,40 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
         if sort_modules:
             self._sort_algebraic_modules()
 
+    def add_algebraic_module_from_args(
+        self,
+        module_name: str,
+        function: Union[Callable[..., float], Callable[..., Iterable[float]]],
+        derived_compounds: List[str],
+        args: List[str],
+        check_consistency: bool = True,
+        sort_modules: bool = True,
+    ) -> None:
+
+        compounds = []
+        modifiers = []
+        parameters = []
+
+        for i in args:
+            if i in self.parameters:
+                parameters.append(i)
+            elif i in self.compounds:
+                compounds.append(i)
+            else:
+                modifiers.append(i)
+
+        self.add_algebraic_module(
+            module_name=module_name,
+            function=function,
+            compounds=compounds,
+            derived_compounds=derived_compounds,
+            modifiers=modifiers,
+            parameters=parameters,
+            args=args,
+            check_consistency=check_consistency,
+            sort_modules=sort_modules,
+        )
+
     def add_algebraic_modules(self, algebraic_modules: dict, meta_info: dict | None = None) -> None:
         """Add multiple algebraic modules to the model.
 
